#
# spec file for package tog-pegasus
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1140 || 0%{?fedora_version} > 14
%define has_systemd 1
%else
%define has_systemd 0
%endif

%{?!PEGASUS_BUILD_TEST_RPM:     %global PEGASUS_BUILD_TEST_RPM        1}
# do "rpmbuild --define 'PEGASUS_BUILD_TEST_RPM 1'" to build test RPM.

%global srcname pegasus
%global major_ver 2.14
%global pegasus_gid 65
%global pegasus_uid 66

%if 0%{?suse_version} > 1310
%define rundir /run
%else
%define rundir /var/run
%endif

Name:           tog-pegasus
Version:        %{major_ver}.1
Release:        3.18
%if 0%{?suse_version}
%else
%endif
Summary:        OpenPegasus WBEM Services for Linux
License:        MIT
Group:          System Environment/Daemons

Url:            http://www.openpegasus.org
Source0:        https://collaboration.opengroup.org/pegasus/documents/32572/pegasus-%{version}.tar.gz
#  1: Description of security enhacements
Source1:        README.SUSE.Security
#  2: Description of SUSE setup
Source2:        README.SUSE
#  3: Description of SSL settings
Source3:        README.SUSE.SSL
#  4: /etc/tmpfiles.d configuration file
Source4:        tog-pegasus.tmpfiles
#  5: systemd service file for RedHat/Fedora
Source5:        tog-pegasus.service
#  6: This file controls access to the Pegasus services by users with the PAM pam_access module
Source6:        access.conf
#  7: Simple Redhat/Fedora wrapper for Pegasus's cimprovagt - because of confining providers in SELinux 
Source7:        cimprovagt-wrapper.sh
#  8: Example wrapper confining Operating System Provider from sblim-cmpi-base package
Source8:        cmpiOSBase_OperatingSystemProvider-cimprovagt.example
#  9: DMTF CIM schema
Source9:        cim_schema_2.38.0Experimental-MOFs.zip
# 10: Fedora/RHEL script for adding self-signed certificates to the local CA
#     trust store
Source10:       generate-certs
# 11: SUSE script for adding self-signed certificates to the local CA
#     trust store
Source11:       generate-certs.SUSE
# 12: systemd service file for SUSE (> 1310)
Source12:       tog-pegasus.service.SUSE
# 13: Simple SUSE wrapper for Pegasus's cimprovagt - because of confining providers in SELinux 
Source13:       cimprovagt-wrapper.sh.SUSE

#  1: http://cvs.rdg.opengroup.org/bugzilla/show_bug.cgi?id=5011
#     Removing insecure -rpath
Patch1:         pegasus-2.9.0-no-rpath.patch
#  2: Adding -fPIE
Patch2:         pegasus-2.7.0-PIE.patch
#  3: http://cvs.rdg.opengroup.org/bugzilla/show_bug.cgi?id=5016
#     Configuration variables
Patch3:         pegasus-2.9.0-redhat-config.patch
#  4: don't see how http://cvs.rdg.opengroup.org/bugzilla/show_bug.cgi?id=5099 fixed it
#     Changing provider dir to the directory we use
Patch4:         pegasus-2.9.0-cmpi-provider-lib.patch
#  5: http://cvs.rdg.opengroup.org/bugzilla/show_bug.cgi?id=5010
#     We distinguish between local and remote user and behave adequately (will be upstream once)
Patch5:         pegasus-2.9.0-local-or-remote-auth.patch
#  6: http://cvs.rdg.opengroup.org/bugzilla/show_bug.cgi?id=5012
#     Modifies pam rules to use access cofiguration file and local/remote differences
%if 0%{?suse_version}
Patch6:         pegasus-SUSE-pam-wbem.patch
%else
Patch6:         pegasus-2.5.1-pam-wbem.patch
%endif
#  9: Adds cimuser binary to admin commands
Patch9:         pegasus-2.6.0-cimuser.patch
# 12: Removes snmp tests, which we don't want to perform
Patch12:        pegasus-2.7.0-no_snmp_tests.patch
# 13: Changes to make package compile on sparc
Patch13:        pegasus-2.9.0-sparc.patch
# 16: Fixes "getpagesize" build error
Patch16:        pegasus-2.9.1-getpagesize.patch
# 19: Don't strip binaries, add -g flag
Patch19:        pegasus-2.10.0-dont-strip.patch
# 20: use posix locks on sparc arches
Patch20:        pegasus-2.10.0-sparc-posix-lock.patch
# 22: Fix CMPI enumGetNext function to change CMPI Data state from default CMPI_nullValue
#     to CMPI_goodValue when it finds and returns next instance correctly
Patch22:        pegasus-2.12.0-null_value.patch
# 24: bz#883030, getPropertyAt() returns Null instead of empty array
Patch24:        pegasus-2.12.0-empty_arrays.patch
# 25: allow experimental schema registration with cimmofl during build
Patch25:        pegasus-2.12.0-cimmofl-allow-experimental.patch
# 26: use external schema and add missing includes there
Patch26:        pegasus-2.12.0-schema-version-and-includes.patch
# 29: bz#1049314, allow unprivileged users to subscribe to indications by default
Patch29:        pegasus-2.13.0-enable-subscriptions-for-nonprivileged-users.patch
# 33: fixes build with gcc5
Patch33:        pegasus-2.13.0-gcc5-build.patch
# 34: fixes various build problemss
Patch34:        pegasus-2.14.1-build-fixes.patch
# 35: fixes compiler warnings
Patch35:        pegasus-2.14.1-fix-compiler-warnings.patch
# 36: 'STACK_OF' undefined
Patch36:        pegasus-2.14.1-openssl.patch

BuildRequires:  bash
BuildRequires:  coreutils
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  grep
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  procps
BuildRequires:  procps
BuildRequires:  sed
%if 0%{?suse_version}
BuildRequires:  cim-schema
BuildRequires:  unzip
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
%else
BuildRequires:  libstdc++
%endif
BuildRequires:  make
BuildRequires:  net-snmp-devel
BuildRequires:  openslp-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
%if 0%{?has_systemd}
BuildRequires:  systemd
%if 0%{?suse_version}
%{?systemd_requires}
%else
BuildRequires:  systemd-units
Requires:       net-snmp-libs
%endif
%endif
%if 0%{?suse_version}
Requires:       %{name}-libs = %{version}-%{release}
%else
Requires:       %{name}-libs = %{version}-%{release}
%endif
Requires:       openssl
%if 0%{?suse_version} > 1130
Requires:       ca-certificates
BuildRequires:  ca-certificates
# for restorecon(8)
BuildRequires:  policycoreutils
Requires:       policycoreutils
%endif
Provides:       cim-server = 1
Requires(post): /sbin/ldconfig
%if 0%{?suse_version}
Requires(post):  /usr/sbin/groupadd
%endif

%description
OpenPegasus WBEM Services for Linux enables management solutions that deliver
increased control of enterprise resources. WBEM is a platform and resource
independent DMTF standard that defines a common information model and
communication protocol for monitoring and controlling resources from diverse
sources.

%package devel
Summary:        The OpenPegasus Software Development Kit
Group:          Development/Tools
%if 0%{?suse_version}
Requires:       libpegclient1
Requires:       libpegcommon1
Requires:       libpegexportserver1
Requires:       libpeglistener1
Requires:       tog-pegasus-libs = %{version}-%{release}
%else
Requires:       tog-pegasus >= %{version}-%{release}
%endif
Provides:       tog-pegasus-sdk = %{version}
Obsoletes:      tog-pegasus-sdk < %{version}
%if 0%{?suse_version}
Provides:       tog-pegasus-devel-internal
# because of /usr/lib64/libcmpiCppImpl.so
Conflicts:      sblim-cmpi-c++-devel
%endif

%description devel
The OpenPegasus WBEM Services for Linux SDK is the developer's kit for the
OpenPegasus WBEM Services for Linux release. It provides Linux C++ developers
with the WBEM files required to build WBEM Clients and Providers. It also
supports C provider developers via the CMPI interface.

%package libs
Summary:        The OpenPegasus Libraries
Group:          System Environment/Libraries
# because of /usr/lib64/libcmpiCppImpl.so.*
Conflicts:      libcmpiCppImpl0
Requires(pre):  /usr/sbin/useradd
Requires(pre):  /usr/sbin/groupadd
Requires(post): /sbin/ldconfig

%description libs
The OpenPegasus libraries.

%if %{PEGASUS_BUILD_TEST_RPM}
%package test
Summary:        The OpenPegasus Tests
Group:          Development/Debug
Requires:       tog-pegasus >= %{version}-%{release}, make

%description test
The OpenPegasus WBEM tests for the OpenPegasus %{version} Linux rpm.
%endif

%if 0%{?suse_version}
%package -n libpegclient1
Summary:        Client library for tog-pegasus
Group:          System Environment/Libraries

%description -n libpegclient1
This is a dependency of tog-pegasus and other associated packages.

%package -n libpegcommon1
Summary:        Common library for tog-pegasus
Group:          System Environment/Libraries

%description -n libpegcommon1
This is a dependency of tog-pegasus and other associated packages.

%package -n libpeglistener1
Summary:        Listener library for tog-pegasus
Group:          System Environment/Libraries

%description -n libpeglistener1
This is a dependency of tog-pegasus and other associated packages.

%package -n libpegexportserver1
Summary:        Exportserver library for tog-pegasus
Group:          System Environment/Libraries

%description -n libpegexportserver1
This is a dependency of tog-pegasus and other associated packages.

%endif

%ifarch ia64
%global PEGASUS_HARDWARE_PLATFORM LINUX_IA64_GNU
%endif
%ifarch x86_64
%global PEGASUS_HARDWARE_PLATFORM LINUX_X86_64_GNU
%endif
%ifarch ppc
%global PEGASUS_HARDWARE_PLATFORM LINUX_PPC_GNU
%endif
%ifarch ppc64
%global PEGASUS_HARDWARE_PLATFORM LINUX_PPC64_GNU
%endif
%ifarch ppc64le
%global PEGASUS_HARDWARE_PLATFORM LINUX_PPC64_GNU
%endif
%ifarch s390
%global PEGASUS_HARDWARE_PLATFORM LINUX_ZSERIES_GNU
%endif
%ifarch s390x
%global PEGASUS_HARDWARE_PLATFORM LINUX_ZSERIES64_GNU
%endif
%ifarch sparcv9
%global PEGASUS_HARDWARE_PLATFORM LINUX_SPARCV9_GNU
%endif
%ifarch sparc64
%global PEGASUS_HARDWARE_PLATFORM LINUX_SPARC64_GNU
%endif
%ifarch %{ix86}
%global PEGASUS_HARDWARE_PLATFORM LINUX_IX86_GNU
%endif
%ifarch %{arm}
%global PEGASUS_HARDWARE_PLATFORM LINUX_XSCALE_GNU
%endif
%ifarch aarch64
%global PEGASUS_HARDWARE_PLATFORM LINUX_AARCH64_GNU
%endif

%global PEGASUS_ARCH_LIB %{_lib}
%global OPENSSL_HOME /usr
%global OPENSSL_BIN /usr/bin
%global PEGASUS_PEM_DIR /etc/Pegasus
%global PEGASUS_SSL_CERT_FILE server.pem
%global PEGASUS_SSL_KEY_FILE file.pem
%global PEGASUS_SSL_TRUSTSTORE client.pem
%global PAM_CONFIG_DIR /etc/pam.d
%global PEGASUS_CONFIG_DIR /etc/Pegasus
%global PEGASUS_VARDATA_DIR /var/lib/Pegasus
%global PEGASUS_VARDATA_CACHE_DIR /var/lib/Pegasus/cache
%global PEGASUS_LOCAL_DOMAIN_SOCKET_PATH %{rundir}/tog-pegasus/socket/cimxml.socket
%global PEGASUS_CIMSERVER_START_FILE %{rundir}/tog-pegasus/cimserver.pid
%global PEGASUS_TRACE_FILE_PATH /var/lib/Pegasus/cache/trace/cimserver.trc
%global PEGASUS_CIMSERVER_START_LOCK_FILE %{rundir}/tog-pegasus/cimserver_start.lock
%global PEGASUS_REPOSITORY_DIR /var/lib/Pegasus/repository
%global PEGASUS_PREV_REPOSITORY_DIR_NAME prev_repository
%global PEGASUS_REPOSITORY_PARENT_DIR /var/lib/Pegasus
%global PEGASUS_PREV_REPOSITORY_DIR /var/lib/PegasusXXX/prev_repository
%global PEGASUS_SBIN_DIR /usr/sbin
%global PEGASUS_DOC_DIR /usr/share/doc/%{name}-%{version}

%global PEGASUS_RPM_ROOT $RPM_BUILD_DIR/%{srcname}
%global PEGASUS_RPM_HOME %PEGASUS_RPM_ROOT/build
%global PEGASUS_INSTALL_LOG /var/lib/Pegasus/log/install.log

%prep
%setup -q -n %{srcname}
# convert DMTF schema for Pegasus
export PEGASUS_ROOT=%PEGASUS_RPM_ROOT
yes | mak/CreateDmtfSchema 238 %{SOURCE9} cim_schema_2.38.0
%patch1 -p1 -b .no-rpath
%patch2 -p1 -b .PIE
%patch3 -p1 -b .redhat-config
%patch4 -p1 -b .cmpi-provider-lib
%patch6 -p1 -b .pam-wbem
%patch9 -p1 -b .cimuser
%patch12 -p1 -b .no_snmp_tests
%patch5 -p1 -b .local-or-remote-auth
%patch13 -p1 -b .sparc
%patch16 -p1 -b .getpagesize
%patch19 -p1 -b .dont-strip
%patch20 -p1 -b .sparc-locks
%patch22 -p1 -b .null_value
%patch24 -p1 -b .empty_arrays
%patch25 -p1 -b .cimmofl-allow-experimental
%patch26 -p1 -b .schema-version-and-includes
%patch29 -p1 -b .enable-subscriptions-for-nonprivileged-users
%patch33 -p1 -b .gcc5-build
%patch34 -p1 -b .build-fixes
%patch35 -p1 -b .compiler-warnings
%patch36 -p1 -b .openssl

%build
cp -fp %SOURCE1 doc
cp -fp %SOURCE3 doc
cp -fp %SOURCE6 rpm
cp -fp %SOURCE8 doc

export PEGASUS_ROOT=%PEGASUS_RPM_ROOT
export PEGASUS_HOME=%PEGASUS_RPM_HOME
export PEGASUS_PLATFORM=%PEGASUS_HARDWARE_PLATFORM
export PEGASUS_ARCH_LIB=%PEGASUS_ARCH_LIB
export PEGASUS_ENVVAR_FILE=$PEGASUS_ROOT/env_var_Linux.status

export OPENSSL_HOME=%OPENSSL_HOME
export OPENSSL_BIN=%OPENSSL_BIN
export LD_LIBRARY_PATH=$PEGASUS_HOME/lib
export PATH=$PEGASUS_HOME/bin:$PATH

export PEGASUS_EXTRA_C_FLAGS="$RPM_OPT_FLAGS -fPIC -g -Wall -Wno-unused -fno-strict-aliasing"
export PEGASUS_EXTRA_CXX_FLAGS="$PEGASUS_EXTRA_C_FLAGS"
export PEGASUS_EXTRA_LINK_FLAGS="$RPM_OPT_FLAGS"
export PEGASUS_EXTRA_PROGRAM_LINK_FLAGS="-g -pie -Wl,-z,relro,-z,now,-z,nodlopen,-z,noexecstack"
export SYS_INCLUDES=-I/usr/kerberos/include

make %{?_smp_mflags} -f ${PEGASUS_ROOT}/Makefile.Release create_ProductVersionFile
make %{?_smp_mflags} -f ${PEGASUS_ROOT}/Makefile.Release create_CommonProductDirectoriesInclude
make %{?_smp_mflags} -f ${PEGASUS_ROOT}/Makefile.Release create_ConfigProductDirectoriesInclude
make %{?_smp_mflags} -f ${PEGASUS_ROOT}/Makefile.Release all
make %{?_smp_mflags} -f ${PEGASUS_ROOT}/Makefile.Release repository

%install
export PEGASUS_ROOT=%PEGASUS_RPM_ROOT
export PEGASUS_HOME=%PEGASUS_RPM_HOME
export PEGASUS_PLATFORM=%PEGASUS_HARDWARE_PLATFORM
export PEGASUS_ARCH_LIB=%PEGASUS_ARCH_LIB
export PEGASUS_ENVVAR_FILE=$PEGASUS_ROOT/env_var_Linux.status

export OPENSSL_BIN=%OPENSSL_BIN
export LD_LIBRARY_PATH=$PEGASUS_HOME/lib
export PATH=$PEGASUS_HOME/bin:$PATH

export PEGASUS_STAGING_DIR=$RPM_BUILD_ROOT
%if %{PEGASUS_BUILD_TEST_RPM}
make -f $PEGASUS_ROOT/Makefile.Release stage \
    PEGASUS_STAGING_DIR=$PEGASUS_STAGING_DIR \
    PEGASUS_BUILD_TEST_RPM=%{PEGASUS_BUILD_TEST_RPM}
%else
make -f $PEGASUS_ROOT/Makefile.Release stage \
    PEGASUS_STAGING_DIR=$PEGASUS_STAGING_DIR
%endif

mkdir -p $RPM_BUILD_ROOT/%{_tmpfilesdir}
install -p -D -m 644 %{SOURCE4} $RPM_BUILD_ROOT/%{_tmpfilesdir}/tog-pegasus.conf

# Install script to generate SSL certificates at startup
mkdir -p $RPM_BUILD_ROOT/usr/share/Pegasus/scripts
%if 0%{?suse_version}
install -p -m 755 %{SOURCE11} $RPM_BUILD_ROOT/usr/share/Pegasus/scripts/generate-certs
%else
install -p -m 755 %{SOURCE10} $RPM_BUILD_ROOT/usr/share/Pegasus/scripts/generate-certs
%endif

# remove SysV initscript, install .service file
rm -f $RPM_BUILD_ROOT/etc/init.d/tog-pegasus
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
%if 0%{?suse_version} > 1310
install -p -m 644 %{SOURCE12} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service
%else
install -p -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{_unitdir}/tog-pegasus.service
%endif
# cimserver_planned.conf is on the right place since 2.9.2 (update - not in 2.10.0)
#mv $RPM_BUILD_ROOT/var/lib/Pegasus/cimserver_planned.conf $RPM_BUILD_ROOT/etc/Pegasus/cimserver_planned.conf
mkdir -p $RPM_BUILD_ROOT/%{_docdir}/%{name}
mv $RPM_BUILD_ROOT/usr/share/doc/%{name}-%{major_ver}/* $RPM_BUILD_ROOT/%{_docdir}/%{name}
rm -rf $RPM_BUILD_ROOT/usr/share/doc/%{name}-%{major_ver}
# create symlink for libcmpiCppImpl
pushd $RPM_BUILD_ROOT/%{_libdir}
ln -s libcmpiCppImpl.so.1 libcmpiCppImpl.so
# and libpeglistener
ln -s libpeglistener.so.1 libpeglistener.so
popd
mkdir -p $RPM_BUILD_ROOT/%{_libexecdir}/pegasus
mv $RPM_BUILD_ROOT/%{_sbindir}/cimprovagt $RPM_BUILD_ROOT/%{_libexecdir}/pegasus
%if 0%{?suse_version}
install -p -m 0755 %{SOURCE13} $RPM_BUILD_ROOT/%{_sbindir}/cimprovagt
%else
install -p -m 0755 %{SOURCE7} $RPM_BUILD_ROOT/%{_sbindir}/cimprovagt
%endif
# install Platform_LINUX_XSCALE_GNU.h because of lmiwbem on arm
install -m 644 src/Pegasus/Common/Platform_LINUX_XSCALE_GNU.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
# install UintArgs.h because of cimple
install -m 644 src/Pegasus/Common/UintArgs.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
# install CIMEnumerationContext.h because of cimple
install -m 644 src/Pegasus/Client/CIMEnumerationContext.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Client
# install Linkage.h and CIMListener.h because of lmiwbem (CIMListener class)
mkdir -p $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Listener
install -m 644 src/Pegasus/Listener/Linkage.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Listener
install -m 644 src/Pegasus/Listener/CIMListener.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Listener
%if 0%{?suse_version}
# install files because of cimple (brevity and cimple-pegasus-adapter)
install -m 644 src/Pegasus/Common/ArrayImpl.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/ArrayInternal.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/ArrayRep.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/AtomicInt.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Buffer.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/CommonUTF.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/InternalException.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Linkable.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Magic.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Memory.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Message.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Mutex.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/PegasusAssert.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Stack.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/StringConversion.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/StrLit.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/Threads.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/XmlGenerator.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/XmlParser.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
install -m 644 src/Pegasus/Common/XmlWriter.h $RPM_BUILD_ROOT/%{_includedir}/Pegasus/Common
%endif

%if 0%{?suse_version}
# Fedora does this in %post :-/

# Create Symbolic Links for SDK Libraries
#
pushd $RPM_BUILD_ROOT/%{_libdir}
ln -sf libpegclient.so.1 libpegclient.so
ln -sf libpegcommon.so.1 libpegcommon.so
ln -sf libpegprovider.so.1 libpegprovider.so
ln -sf libpegconfig.so.1 libpegconfig.so
ln -sf libpegprm.so.1 libpegprm.so
ln -sf libpegprovidermanager.so.1 libpegprovidermanager.so
ln -sf libDefaultProviderManager.so.1 libDefaultProviderManager.so
ln -sf libCIMxmlIndicationHandler.so.1 libCIMxmlIndicationHandler.so
ln -sf libsnmpIndicationHandler.so.1 libsnmpIndicationHandler.so
popd

# Create Symbolic Links for Packaged Provider Libraries
#
pushd $RPM_BUILD_ROOT/%{_libdir}/Pegasus/providers
ln -sf libComputerSystemProvider.so.1 libComputerSystemProvider.so
ln -sf libOSProvider.so.1 libOSProvider.so
ln -sf libProcessProvider.so.1 libProcessProvider.so
popd

# Create Symbolic Links for Packaged Provider Managers
#
pushd $RPM_BUILD_ROOT/%{_libdir}/Pegasus/providerManagers/
ln -sf libCMPIProviderManager.so.1 libCMPIProviderManager.so
popd

# no binaries below /usr/share
mv $RPM_BUILD_ROOT%{_datadir}/Pegasus/test $RPM_BUILD_ROOT%{_libdir}/Pegasus
%if 0%{?suse_version} > 1010
%fdupes -s $RPM_BUILD_ROOT%{_bindir}
%fdupes -s $RPM_BUILD_ROOT/var/lib/Pegasus
%endif
ln -sf %{_sbindir}/service $RPM_BUILD_ROOT%{_sbindir}/rc%{name}
%endif

%check
# run unit tests
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT/usr/%{_lib}
%if 0%{?suse_version}
cd $RPM_BUILD_ROOT%{_libdir}/Pegasus/test
%else
cd $RPM_BUILD_ROOT/usr/share/Pegasus/test
%endif
make prestarttests

%files
%defattr(0640, root, pegasus, 0750)
%verify(not md5 size mtime mode group) /var/lib/Pegasus/repository
%defattr(0644, root, pegasus, 0755)
/usr/share/Pegasus/mof
%dir /usr/share/Pegasus
%defattr(0755, root, pegasus, 0750)
/usr/share/Pegasus/scripts
%defattr(0640, root, pegasus, 0750)
%dir /var/lib/Pegasus
/var/lib/Pegasus/cache
%if 0%{?suse_version}
/var/lib/Pegasus/repository
%endif
%dir /var/lib/Pegasus/log
%defattr(0640, root, pegasus, 0750)
%dir /etc/Pegasus
%{_tmpfilesdir}/tog-pegasus.conf
%if 0%{?suse_version} == 0
%ghost %dir %{rundir}/%{name}
%ghost %attr(0640, root, pegasus) %{rundir}/%{name}/cimserver.pid
%ghost %attr(0640, root, pegasus) %{rundir}/%{name}/cimserver_start.lock
%ghost %attr(1640,root,pegasus) %{rundir}/%{name}/cimxml.socket
%endif
%attr(0644, root, pegasus) %{_unitdir}/tog-pegasus.service
%defattr(0640, root, pegasus, 0750)
%ghost %attr(0640, root, pegasus) %config(noreplace) /etc/Pegasus/cimserver_current.conf
%ghost %config(noreplace) /etc/Pegasus/cimserver_planned.conf
%config(noreplace) /etc/Pegasus/access.conf
%config(noreplace) /etc/pam.d/wbem
%ghost /etc/Pegasus/ssl.cnf
%ghost /etc/Pegasus/client.pem
%ghost /etc/Pegasus/server.pem
%ghost /etc/Pegasus/file.pem
%ghost /etc/Pegasus/ca.crt
%ghost /etc/Pegasus/ca.srl
%ghost /etc/Pegasus/client.srl
%ghost /etc/Pegasus/ssl-ca.cnf
%ghost /etc/Pegasus/ssl-service.cnf
%if 0%{?suse_version}
%ghost /etc/pki/trust/anchors/localhost-pegasus.pem
%else
%ghost /etc/pki/ca-trust/source/anchors/localhost-pegasus.pem
%endif
%ghost %attr(0640, root, pegasus) /etc/Pegasus/cimserver_trust
%ghost %attr(0640, root, pegasus) /etc/Pegasus/indication_trust
%ghost %attr(0640, root, pegasus) /etc/Pegasus/crl
%ghost %verify(not md5 size mtime) /var/lib/Pegasus/log/install.log
%ghost %attr(0640, root, pegasus) %verify(not md5 size mtime) /var/lib/Pegasus/cache/trace/cimserver.trc
%defattr(0755, root, pegasus, 0755)
/usr/sbin/*
/usr/bin/*
%dir %{_libexecdir}/pegasus/
%{_libexecdir}/pegasus/
%defattr(0644, root, pegasus, 0755)
/usr/share/man/man8/*
/usr/share/man/man1/*
%doc doc/license.txt doc/Admin_Guide_Release.pdf
%doc doc/PegasusSSLGuidelines.htm doc/SecurityGuidelinesForDevelopers.html
%doc doc/README.SUSE.Security src/Clients/repupgrade/doc/repupgrade.html
%doc doc/README.SUSE.SSL doc/cmpiOSBase_OperatingSystemProvider-cimprovagt.example

%files devel
%defattr(0644,root,pegasus,0755)
%{_libdir}/*.so
/usr/share/Pegasus/samples
/usr/include/Pegasus
/usr/share/Pegasus/html

%files libs
%defattr(0755, root, pegasus, 0750)
%{_libdir}/*.so.*
%if 0%{?suse_version}
%exclude %{_libdir}/libpegclient.so.1
%exclude %{_libdir}/libpegslp_client.so.1
%exclude %{_libdir}/libpegcommon.so.1
%exclude %{_libdir}/libpegexportserver.so.1
%exclude %{_libdir}/libpeglistener.so.1
%endif
%dir %{_libdir}/Pegasus
%{_libdir}/Pegasus/providers
%{_libdir}/Pegasus/providerManagers
%exclude %{_libexecdir}/pegasus
%exclude /usr/lib/systemd
%exclude %{_tmpfilesdir}
%if 0%{?suse_version}
%exclude %{_libdir}/Pegasus/test
%endif

%if 0%{?suse_version}
%files -n libpegclient1
%defattr(-,root,root,-)
%{_libdir}/libpegclient.so.1
%{_libdir}/libpegslp_client.so.1

%files -n libpegcommon1
%defattr(-,root,root,-)
%{_libdir}/libpegcommon.so.1

%files -n libpeglistener1
%defattr(-,root,root,-)
%{_libdir}/libpeglistener.so.1

%files -n libpegexportserver1
%defattr(-,root,root,-)
%{_libdir}/libpegexportserver.so.1
%endif

%if %{PEGASUS_BUILD_TEST_RPM}
%files test
%defattr(0644,root,pegasus,0755)
%if 0%{?suse_version}
%dir %{_libdir}/Pegasus/test
%{_libdir}/Pegasus/test/log.trace.0
%{_libdir}/Pegasus/test/testtracer4.trace.0
%{_libdir}/Pegasus/test/Makefile
%{_libdir}/Pegasus/test/mak
%dir %{_libdir}/Pegasus/test/tmp
%ghost %{_libdir}/Pegasus/test/tmp/procIdFile
%ghost %{_libdir}/Pegasus/test/tmp/trapLogFile
%ghost %{_libdir}/Pegasus/test/tmp/IndicationStressTestLog
%ghost %{_libdir}/Pegasus/test/tmp/oldIndicationStressTestLog
%verify(not md5 size mtime) /var/lib/Pegasus/testrepository
%defattr(0750,root,pegasus,0755)
%{_libdir}/Pegasus/test/bin
%{_libdir}/Pegasus/test/%PEGASUS_ARCH_LIB
%else
%dir /usr/share/Pegasus/test
/usr/share/Pegasus/test/log.trace.0
/usr/share/Pegasus/test/testtracer4.trace.0
/usr/share/Pegasus/test/Makefile
/usr/share/Pegasus/test/mak
%dir /usr/share/Pegasus/test/tmp
%ghost /usr/share/Pegasus/test/tmp/procIdFile
%ghost /usr/share/Pegasus/test/tmp/trapLogFile
%ghost /usr/share/Pegasus/test/tmp/IndicationStressTestLog
%ghost /usr/share/Pegasus/test/tmp/oldIndicationStressTestLog
%verify(not md5 size mtime) /var/lib/Pegasus/testrepository
%defattr(0750,root,pegasus,0755)
/usr/share/Pegasus/test/bin
/usr/share/Pegasus/test/%PEGASUS_ARCH_LIB
%endif
%endif

%pre
%if 0%{?suse_version}
if [ -f /var/lib/systemd/migrated/%{name} ]; then
%service_add_pre %{name}.service
fi
%endif
if [ $1 -gt 1 ]; then
   if [ -d /var/lib/Pegasus/repository ]; then
        if [ -d /var/lib/Pegasus/prev_repository ]; then
           rm -rf /var/lib/Pegasus/prev_repository
        fi;
        mv /var/lib/Pegasus/repository /var/lib/Pegasus/prev_repository;
   fi
fi
:;

%post
install -d -m 1750 -o root -g pegasus %{rundir}/%{name}
%if 0%{?suse_version}
/usr/sbin/groupadd -r wbem >/dev/null 2>&1 || :
%service_add_post %{name}.service
%else
restorecon %{rundir}/%{name}
/sbin/ldconfig;
%systemd_post tog-pegasus.service
%endif
if [ $1 -ge 1 ]; then
   echo `date` >>  /var/lib/Pegasus/log/install.log 2>&1 || :;
   if [ $1 -gt 1 ]; then
      if [ -d /var/lib/Pegasus/prev_repository ]; then
        echo "prev_repository exists, running repupgrade" >>  /var/lib/Pegasus/log/install.log 2>&1 || :;
        mkdir -p /var/lib/Pegasus/repository
         ls /var/lib/Pegasus >>  /var/lib/Pegasus/log/install.log 2>&1 || :;
      #  The user's old repository was moved to /var/lib/Pegasus/prev_repository, which 
      #  now must be upgraded to the new repository in /var/lib/Pegasus/repository:
         /usr/sbin/repupgrade 2>> /var/lib/Pegasus/log/install.log || :;
         echo "repupgrade done" >>  /var/lib/Pegasus/log/install.log 2>&1 || :;
         ls /var/lib/Pegasus >>  /var/lib/Pegasus/log/install.log 2>&1 || :;
      fi;
      /bin/systemctl try-restart tog-pegasus.service >/dev/null 2>&1 || :;
   fi;
fi
:;

%preun
%if 0%{?suse_version}
%service_del_preun %{name}.service
%else
%systemd_preun stop tog-pegasus.service
%endif
if [ $1 -eq 0 ]; then                  
   # Package removal, not upgrade     
   rm -rf %{rundir}/%{name}
fi
:;

%postun
/sbin/ldconfig
%if 0%{?suse_version}
%service_del_postun %{name}.service
%else
%systemd_postun_with_restart tog-pegasus.service
%endif

%preun devel
if [ $1 -eq 0 ] ; then
   make --directory /usr/share/Pegasus/samples -s clean >/dev/null 2>&1 || :;
fi
:;

%pre libs
if [ $1 -eq 1 ]; then
#  first install: create the 'pegasus' user and group:
   /usr/sbin/groupadd -g %{pegasus_gid} -f -r pegasus >/dev/null 2>&1 || :; 
   /usr/sbin/useradd -u %{pegasus_uid} -r -N -M -g pegasus -s /sbin/nologin -d /var/lib/Pegasus \
     -c "tog-pegasus OpenPegasus WBEM/CIM services" pegasus >/dev/null 2>&1 || :;
fi
:;

%if 0%{?suse_version}
%post libs -p /sbin/ldconfig
%else
%post libs
if [ $1 -eq 1 ]; then
   # Create Symbolic Links for SDK Libraries
   #
   ln -sf libpegclient.so.1 /usr/%PEGASUS_ARCH_LIB/libpegclient.so
   ln -sf libpegcommon.so.1 /usr/%PEGASUS_ARCH_LIB/libpegcommon.so
   ln -sf libpegprovider.so.1 /usr/%PEGASUS_ARCH_LIB/libpegprovider.so
   ln -sf libDefaultProviderManager.so.1 /usr/%PEGASUS_ARCH_LIB/libDefaultProviderManager.so
   ln -sf libCIMxmlIndicationHandler.so.1 /usr/%PEGASUS_ARCH_LIB/libCIMxmlIndicationHandler.so
   ln -sf libsnmpIndicationHandler.so.1 /usr/%PEGASUS_ARCH_LIB/libsnmpIndicationHandler.so

   # Create Symbolic Links for Packaged Provider Libraries
   #
   ln -sf libComputerSystemProvider.so.1 /usr/%PEGASUS_ARCH_LIB/Pegasus/providers/libComputerSystemProvider.so
   ln -sf libOSProvider.so.1 /usr/%PEGASUS_ARCH_LIB/Pegasus/providers/libOSProvider.so
   ln -sf libProcessProvider.so.1 /usr/%PEGASUS_ARCH_LIB/Pegasus/providers/libProcessProvider.so

   # Create Symbolic Links for Packaged Provider Managers
   #
   ln -sf libCMPIProviderManager.so.1 /usr/%PEGASUS_ARCH_LIB/Pegasus/providerManagers/libCMPIProviderManager.so

   # Change ownership of Symbolic Links to the 'pegasus' group
   #
   /bin/chgrp -h pegasus /usr/%{_lib}/libpegclient.so
   /bin/chgrp -h pegasus /usr/%{_lib}/libpegcommon.so 
   /bin/chgrp -h pegasus /usr/%{_lib}/libpegprovider.so
   /bin/chgrp -h pegasus /usr/%{_lib}/libDefaultProviderManager.so
   /bin/chgrp -h pegasus /usr/%{_lib}/libCIMxmlIndicationHandler.so
   /bin/chgrp -h pegasus /usr/%{_lib}/libsnmpIndicationHandler.so
   /bin/chgrp -h pegasus /usr/%{_lib}/Pegasus/providers/libComputerSystemProvider.so
   /bin/chgrp -h pegasus /usr/%{_lib}/Pegasus/providers/libOSProvider.so
   /bin/chgrp -h pegasus /usr/%{_lib}/Pegasus/providers/libProcessProvider.so
   /bin/chgrp -h pegasus /usr/%{_lib}/Pegasus/providerManagers/libCMPIProviderManager.so
fi
:;
/sbin/ldconfig
%endif

%postun libs -p /sbin/ldconfig

%post test -p /sbin/ldconfig

%postun test -p /sbin/ldconfig

%if 0%{?suse_version}
%post -n libpegclient1 -p /sbin/ldconfig
%postun -n libpegclient1 -p /sbin/ldconfig

%post -n libpegcommon1 -p /sbin/ldconfig
%postun -n libpegcommon1 -p /sbin/ldconfig

%post -n libpeglistener1 -p /sbin/ldconfig
%postun -n libpeglistener1 -p /sbin/ldconfig

%post -n libpegexportserver1 -p /sbin/ldconfig
%postun -n libpegexportserver1 -p /sbin/ldconfig
%endif

%changelog
* Fri Jun 19 2015 kkaempf@suse.com
- Fix SLE 11 build
* Wed Jun 10 2015 kkaempf@suse.com
- Adapt to openssl-1.0.2a (pegasus-2.14.1-openssl.patch)
* Tue Jun  2 2015 kkaempf@suse.com
- Add more include files to tog-pegasus-devel to build 'cimple'
* Tue Apr 21 2015 kkaempf@suse.com
- Update to 2.14.1
  See https://collaboration.opengroup.org/pegasus/pp/documents/32512/ReleaseNotes.htm
  for full list of changes
- fix build
  - pegasus-2.14.1-build-fixes.patch
  - pegasus-2.14.1-fix-compiler-warnings.patch
- remove upstream patches
  - pegasus-2.13.0-PG_ComputerSystem.CreationClassName.patch
  - pegasus-2.13.0-build-fix.patch
  - pegasus-2.13.0-SSLGeneration.patch
  - pegasus-2.13.0-CMGetKey-data-type-fix.patch
  - pegasus-2.13.0-wrong-embedded-instances-from-cimom-callback.patch
* Tue Mar 24 2015 kkaempf@suse.com
- Create group 'wbem' in tog-pegasus %%post script
- Added conflicts
  tog-pegasus-devel with sblim-cmpi-c++-devel
  tog-pegasus-libs with libcmpiCppImpl0
* Fri Mar 20 2015 kkaempf@suse.com
- Add generate-certs.SUSE
* Tue Mar 10 2015 kkaempf@suse.com
- Adapt Fedora packaging
  * Added patches
    pegasus-2.10.0-dont-strip.patch
    pegasus-2.10.0-sparc-posix-lock.patch
    pegasus-2.12.0-cimmofl-allow-experimental.patch
    pegasus-2.12.0-empty_arrays.patch
    pegasus-2.12.0-null_value.patch
    pegasus-2.12.0-schema-version-and-includes.patch
    pegasus-2.13.0-build-fix.patch
    pegasus-2.13.0-CMGetKey-data-type-fix.patch
    pegasus-2.13.0-enable-subscriptions-for-nonprivileged-users.patch
    pegasus-2.13.0-gcc5-build.patch
    pegasus-2.13.0-PG_ComputerSystem.CreationClassName.patch
    pegasus-2.13.0-SSLGeneration.patch
    pegasus-2.13.0-wrong-embedded-instances-from-cimom-callback.patch
    pegasus-2.5.1-pam-wbem.patch
    pegasus-SUSE-pam-wbem.patch
    pegasus-2.6.0-cimuser.patch
    pegasus-2.7.0-no_snmp_tests.patch
    pegasus-2.7.0-PIE.patch
    pegasus-2.9.0-cmpi-provider-lib.patch
    pegasus-2.9.0-local-or-remote-auth.patch
    pegasus-2.9.0-no-rpath.patch
    pegasus-2.9.0-redhat-config.patch
    pegasus-2.9.0-sparc.patch
    pegasus-2.9.1-getpagesize.patch
  * Removed patches
    pegasus-2.13.0-allow-unused.patch
    pegasus-2.13.0-config.patch
    pegasus-2.13.0-defineable-user.patch
    pegasus-2.13.0-no-return-in-nonvoid-function.patch
    pegasus-2.13.0-notests.patch
    pegasus-2.7.0-strncat.patch
    pegasus-no-strip.patch
    pegasus-pam-wbem.patch
* Fri Dec 13 2013 kkaempf@suse.com
- Update to 2.13.0
  Features
  - PEP 304 Enhance repupgrade utility to support "interop" namespace
  - PEP 365 Add support for PUSH_WITH_ACK delivery mode for WSMAN
    indications
  Bugfixes
  - Bug 9645 Change default Schema version to use CIM Schema 2.36
  - Bug 9635 IPV6 support for OpenPegasus slp using OpenSLP 2.0
  - Bug 9643 Role-based authorization extension for CMPI providers
  See https://collaboration.opengroup.org/pegasus/pp/documents/29166/ReleaseNotes.htm
  for full release notes.
* Thu Mar 28 2013 kkaempf@suse.com
- Update to 2.12.1
  Minor bugfix release
* Sat Nov 24 2012 kkaempf@suse.com
- Splitt off libpegclient1, libpegcommon1, libpegexportserver1
  and libpeglistener1 as sub-packages to use by tools
  (i.e. cimlistener from cimple)
* Sat Nov 24 2012 kkaempf@suse.com
- Remove 'Authors' from %%description
* Tue Oct 16 2012 kkaempf@suse.com
- Update to 2.12.0 final release
  Features
  - PEP 360 Provider Lifecycle Indications
  - PEP 361 cimcli support for embedded instances
  - PEP 304 Allow modification of name of interop namespace
  - PEP 358 WSMan indication handling and subscription support
  Bugfixes
  - Bug 8891 Enhance cimsub to add operations to create filters,
    destinations and subscriptions
  - Bug 5667 Remove experimental form buildInstance and filter
    functions in CIMInstance class
  - Bug 8952 Support Configurable cipher suites in OpenPegasus
  - Bug 8984 Add support for indication deliver connection pooling
  - Bug 9008 Add new Indication runtime configuration variables:
    maxIndicaitonDeliveryRetry Attempts  and
    minIndicationdeliveryRetryInterval
  - Bug 9013 Enable ordered indication delivery from provider through
    CIMServer when PEGASUS_ENABLE_DMTF_INDICATION_PROFILE compile
    flag is set
  - Bug 9080 Guaranteed provider lifecycle indication delivery during
    CIMServer shutdonw
  - Bug 9112 Advertise IndicationService conformance to Indications Profile
    by imlementing CIM_ElementConformsToProfile when
    PEGASUS_ENABLE_DMTF_INDICATION_PROFILE_SUPPORT defined
  - Bug 9114 Advertise DMTF Indications Profile (DSP1054) 1.1.0 conformance
  - Bug 9118 Add support for CIM_IndicationFilter.SourceNamespaces[]
    property
  - Bug 9136 Runtime configuration option to restrict cimserver to listen
    on selected network interfaces
  - Bug 9155 Update to include CIM 2.31 Schema and set this as default
    schema
  - Bug 9159 Add SSL Support to Dynamic Listener
  - Bug 9172 Add capability for administrator to override hostname used
    by providers. This adds  new runtime configuration variable
    hostname and fullyQualifiedHostName. It is necessary to
    upgrade existing repositories using repupgrade utility when
    upgrading from OpenPegasus less that 2.12.0 and reusing an
    existing repository.
  - Bug 9215 Add support of CQL query language to ExecQuery operation in
    general. When the server receives  ExecQuery it executes
    enumerate instance for providers that do not support ExecQuery
    and filters result.
  - Bug 9209 Add operations for display class tree and counting instances
    to cimcli
  - Bug 9227 Enhance cimsub for batches of subscription oriented operations
  - Bug 9229 Add gcc build support on hp-ux for the Common, Client and
    General libraries.
  - Bug 9236 Support for clang/clang++ compiler on Linux. This version
    supports only X86 and X86_64 and requires clang version 3
    or greater.
* Wed Sep 26 2012 kkaempf@suse.com
- Fix Fedora and RHEL6 build failures
* Wed Sep 26 2012 kkaempf@suse.com
- Update to 2.12.0 pre-release
* Tue Apr  3 2012 kkaempf@suse.com
- Fix CentOS build
* Fri Mar  2 2012 kkaempf@suse.com
- Package pkgconfig in -devel only,
  make -devel-internal require -devel
* Thu Mar  1 2012 kkaempf@suse.com
- Re-add CMPI header files to tog-pegasus-devel
- don't conflict with sblim-cpmi-devel any more
* Tue Feb 28 2012 kkaempf@suse.com
- Fix build on openSUSE 12.1/Factory
* Fri Sep 16 2011 kkaempf@suse.com
- Update to 2.11.1
  minor release
  - PEP 318 Run 32 bit providers in 64 bit OpenPegasus
  - PEP 356 Provider Module Grouping
  - PEP 357 SNMP V3 Trap Generation in Pegasus Indication Handler
  - PEP 324 DMTF Indications Profile (DSP 1054) Implementation, stage 2
  - PEP 349 Improve the availability of the CIMOM by better isolation
    from faulty providers
  - Bug 8787 Add External SLP support to release builds
  - Bug 8800 enable PEGASUS_USE_RELEASE_CONFIG_OPTIONS build option
    to have true/false values
  - Bug 8806 Diagnose data for BAD UTF8 exception
  - Bug 8825 Option to specify multiple provider dirs for release builds
  - Bug 8839 OOP Provider recovery enhancement
  - Bug 8845 Enhance SSL Certificate info to expose the whole certificate
  - Bug 8871 Enhance WSMan Server Adpater to include enumeration
    association filters
  - Bug 9036 New runtime configuration options for Indication Service
  - Bug 9014 Correct issue with Provider backward compatibility due to
    a new virtual function that was introduced in Pegasus 2.11.0
- Version 2.10
  - PEP 311 WS-Management Support in CIM Server - Phase II.
    NOTE: This is an update of the same PEP number that
  incorporated WS_Management changes to Pegasus 2.9.0 to
  incorporate more WS_Management functionality.
  - PEP 283 Extend CIMCLI to create/modify instances with other features
  - PEP 348 Single-Memory-Object for CMPI structure
  - PEP 347 Separate Internal Modules from Common Library
  - PEP 350 Multi CIMOM support on same OS
  - Bug 8525 repupgrade utility enhancement to update SystemName property
    in indication filter/handler and ObjectManager instances
  - Bug 8406 Indication service can be disabled/enabled dynamically
* Wed Dec  1 2010 kkaempf@novell.com
- Update to 2.9.2
  - PEP 311 WS-Management Support in CIM Server - Phase II
  - PEP 314 SQLite Repository
  - PEP 316 In-Memory-Tracing
  - PEP 328 Solaris 11 (Nevada) support for CC compiler and IX86
  - Bug 7902 Allow modifyClass on non-leaf class
  - Bug 7996 64 bit platform support for z/OS
  - Bug 8074 Significant performance enhancement in out-of-process
    providers (~ 300%%) through binary protocol
  - Bug 8171 Access to binary protocol for clients
* Wed Sep 15 2010 kkaempf@novell.com
- Fix RH/Fedora builds
* Sun May  2 2010 aj@suse.de
- Handle /var/run on tmpfs.
- Provide pkg-config provides.
* Tue Apr 20 2010 meissner@suse.de
- fix build with openssl 1.0
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep  2 2009 mhrusecky@suse.cz
- using echo instead of print in shell script loadmof.sh
- searching for mof_compiler.py in versioned python directory too
* Wed Aug 12 2009 mhrusecky@suse.cz
- better condition in one if (minor code cleanup) [bnc#517722]
* Mon May 25 2009 mhrusecky@suse.cz
- repository is owned by pegasus user and daemon is running as pegasus as well
- 'rctog-pegasus start' fixed so second run wouldn't try to run same daemon again
* Thu May 21 2009 mhrusecky@suse.cz
- updated to version 2.9.0
* Mon May 18 2009 mhrusecky@suse.cz
- fixed build in Factory
* Tue May 12 2009 mhrusecky@suse.cz
- adding conflict with sblim-cmpi-devel to spec file
* Thu Nov 20 2008 mhrusecky@suse.cz
- adding %%fdupes into the spec file to fix build on ia64
  (same build ID in nonidentical files broke extracting debug info)
* Fri Nov  7 2008 ro@suse.de
- move pkgconfig creation out of specfile (confuses parser ...)
- add python-httplib2 and openssl to buildrequires to fix build
* Fri Sep 19 2008 bwhiteley@suse.de
- Put %%_libdir/*.so files back in the main package, as many of
  them need to be there.
- Removed Python provider manager from this package.  It is in a
  separate package now due to pluggable provider manager support
  in Pegasus 2.8.  Also, CMPI-based Python providers are now
  preferred (cmpi-bindings project within http://omc-project.org/)
- Disable building of most test code.
- Remove test-internal subpackage.
* Fri Sep 19 2008 mmarek@suse.cz
- updated to 2.8.0
  new features in this version:
  * Memory Resident Repository (PEP 307)
  * WS-Management Support in CIM Server 	 (PEP 311)
  * Pluggable Provider Managers - Enhancement (PEP 313)
  * Tracing in OpenPegasus - Enhancement (PEP 315)
  * Profile Registration Profile Support (PEP 319)
  * Track Generated Indications Data (PEP 322)
  * DMTf Indication Profile Implementation, Stage 1 (DMTF DSP 1054)
    (PEP 323)
  * Track Generated Indications Data (PEP 322)
* Mon Aug 18 2008 mmarek@suse.de
- use LSB keywords instead of X-UnitedLinux-* in the init script
* Tue Jul 15 2008 mmarek@suse.cz
- only put folowing .so files into the main package (bnc#341368):
  %%_libdir/Pegasus/*/*.so
  %%_libdir/lib*Handler.so
  everything else goes to the -devel subpackage
* Fri Jul  4 2008 mmarek@suse.cz
- split /usr/include/Pegasus-internal into devel-internal
  subpackage
* Mon May 12 2008 mmarek@suse.cz
- drop provider-register.sh usage in peg-loadmof.sh, it can't find
  MOFs in /usr/share/mof/* (bnc#389134)
* Mon May 12 2008 mmarek@suse.cz
- don't install internal headers executable
* Thu Apr 17 2008 npaxton@novell.com
- install non-frozen headers to /usr/include/Pegasus-internal
* Thu Apr  3 2008 bwhiteley@suse.de
- Renamed README.SuSE.Security to README.SUSE.Security.
- Patch to allow connection to UDS with credentials (pegasus_bug:7563).
* Mon Mar 24 2008 npaxton@novell.com
- Add pluggable provider manager patch
* Thu Mar 20 2008 mmarek@suse.cz
- cim-schema is also used in %%%%post
* Thu Mar 20 2008 mmarek@suse.cz
- Changed the python-pywbem dependency to PreReq, as it is used
  in %%%%post.
- Synced *.changes and %%%%changelog in the specfile
* Thu Feb 28 2008 jcarey@novell.com
- Changed to use copy of given OperationContext when making up
  calls to the CIMOM. Fixes problem where the requesting user
  name was not being used when making these calls. The user
  identity was not available to providers.
* Fri Feb 22 2008 bwhiteley@suse.de
- Don't build root/cimv2 namespace during build.  Create it during
  install instead with new python MOF compiler.  Don't register any
  PG providers by default.
* Wed Feb 20 2008 jcarey@novell.com
- Changed to not allow exception to be thrown from the
  processMessage method of the provider manager.
* Fri Feb 15 2008 bwhiteley@suse.de
- Make cimsrvr user a member of the pegasus group.  Otherwise,
  in-process providers do not work.
* Sat Feb  9 2008 bwhiteley@suse.de
- Allow root user to log in from remote (bnc#344466)
* Tue Feb  5 2008 jcarey@novell.com
- Changed so the default action is performed when a SIGCHLD signal
  is received (pegasus-sigchld.patch).
* Fri Feb  1 2008 bwhiteley@suse.de
- Changed peg-loadmof.sh to use new pywbem MOF compiler instead of
  Pegasus MOF compiler.
- Fixed the python provider manager to cleanly unload providers.
* Mon Jan 21 2008 mmarek@suse.cz
- copy repository to prev_repository instead of rename, to make
  patchrpms happy
* Fri Jan 11 2008 mmarek@suse.cz  
- run repupgrade on package update [#349347]
* Thu Jan 10 2008 bwhiteley@suse.de
- Added a new file with build options, instead of patching the one
  that comes with the project.
- Changed PEGASUS_CLASS_CACHE_SIZE=30
- Changed PEGASUS_DEFAULT_USERCTXT_REQUESTOR=true
- Disabled PEGASUS_USE_RELEASE_CONFIG_OPTIONS.  When this is enabled, it's
  impossible to change the listen port numbers.
- Created a new cimserver_planned.conf with all runtime options present
  and documented.
* Tue Jan  8 2008 mmarek@suse.cz
- reduced BuildRequires (enables SLES9 build in the buildservice)
* Mon Jan  7 2008 mmarek@suse.cz
- synced with the systemsmanagement:wbem buildservice project
  * set authorizedUserGroups=pegasus in config
  * updated the python provider interface
  * added pegutil script to start a minimal cimserver on demand
    to simplify loadmof.sh
  * updated pegasus-config.patch
  * send content-length header in 401 case in XmlWriter.cpp
    (pegasus-http401-content-length.patch)
  * move the .so symlinks back to the main package for now
    [#341368]
* Mon Dec  3 2007 mmarek@suse.cz
- fixed incorrect strncat() call in OperatingSystem_Linux.cpp
* Tue Nov 27 2007 bwhiteley@suse.de
- Added python provider interface.
* Thu Nov 15 2007 mmarek@suse.cz
- add .so symlinks for all installed libraries [#341368] and move
  them to -devel
* Fri Nov  2 2007 mmarek@suse.cz
- reduced BuildRequires
* Wed Oct 31 2007 mmarek@suse.cz
- added a workaround for a gcc bug [#337901, gcc.gnu.org/PR31081]
  to fix BETA build
* Tue Oct 30 2007 mmarek@suse.cz
- updated to 2.7.0
  new features in this version:
  * Add Platform support IBM i5/PASE - Portable Application
    Solutions Environment (PASE) (PEP 284)
  * Reduce the Amount of CIM Server code that runs Privileged
    (Privilege Separation) (PEP 286)
  * Add Support for IPv6 - Stage 1 (Note: This functionality was
    made available but normally disabled Pegasus 2.6.1) (PEP 291)
  * Add IPV6 Support for SNMP Indication Handler and include
    NET-SNMP indication handler in Linux RPM (PEP 62)
  * Enhanced Log File Support (PEP 302)
  * Add support for certificate-based authentication audit logging
    (PEP 258)
  * Add two new trace components to facilitate triage of indication
    delivery issues (bug 6466)
  new features from 2.6.0:
  * Embedded Instance Support in Pegasus (PEP 233)
  * Providing SMI-Server Profile through OpenPegasus (PEP 244)
  * Incorporation of CIM_Error into OpenPegasus Infrastructure
    (PEP 245)
  * Language Interfaces (PEP 246)
  * Reducing Pegasus Code size and static memory usage (PEP 255)
  * Indication Subscription Management (PEP 257)
  * Audit Logging (PEP 258)
  * SSL Certificate Management Command Interfaces (PEP 259)
  * CMPI 2.0 Currency (PEP 260)
  * SLP enhancements for Pegasus 2.6 (PEP 267)
  * Repository Archive (PEP 271)
- rewrote the specfile from scratch
- updated the local-or-remote patch to support IPv6 and privilege
  separation
* Sat Aug 11 2007 dmueller@suse.de
- rename test package to test-internal and remove
  it from production state (fixes build)
* Thu Jan 18 2007 mrueckert@suse.de
- prefixed loadmof.sh and rmmof.sh with "peg-"
  and require cim-schema. (#228349|FATE #301801)
* Thu Jan 18 2007 mrueckert@suse.de
- add symlink for libcmpiCppImpl.so.1 to
  libcmpiCppImpl.so and install the CMPI headers (#233452)
* Thu Nov 16 2006 mrueckert@suse.de
- make sure all manpages are world readable (#209441)
* Tue Jul 11 2006 mrueckert@suse.de
- build tests rpm
- move *.so symlinks into the base package. needed for plugin
  loading.
- create ssl certs in the init script if needed
- properly handle return codes in provider-register.sh
- set "repositoryIsDefaultInstanceProvider=true" so sblim-gather
  can register properly
* Mon Jul 10 2006 mrueckert@suse.de
- obsolete/provide pegasuse-wbem
* Mon Jul 10 2006 mrueckert@suse.de
- comment out the Requires(post|pre|postun) for now
* Fri Jul  7 2006 mrueckert@suse.de
- dont package the debug files in the base package
* Fri Jul  7 2006 mrueckert@suse.de
- Initial package based on the fedora core 6 package
